@@ -64,8 +64,6 @@ Line:'cascmd_fr917.html',
 LineHorz:'cascmd_fr091.html',
 LineTan:'cascmd_fr093.html',
 LineVert:'cascmd_fr092.html',
-M:'cascmd_fr014.html',
-NUM:'cascmd_fr838.html',
 NewFold:'cascmd_fr080.html',
 Note_ind:'cascmd_fr002.html',
 Nullspace:'cascmd_fr622.html',
@@ -1328,5 +1326,5 @@ xor:'cascmd_fr138.html',
 xyztrange:'cascmd_fr893.html',
 zeros:'cascmd_fr270.html',
 zip:'cascmd_fr542.html',
-ztrans:'cascmd_fr702.html'
+ztrans:'cascmd_fr702.html',
 };
